@@ -185,6 +185,7 @@ static void
 gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 {
 	GtkWidget *scrolled_window, *hbox, *vbox;
+	GtkWidget *content_area;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
 	GConfClient *client;
@@ -192,9 +193,11 @@ gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 200);
 	
@@ -245,7 +248,7 @@ gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 	
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->delete_button, FALSE, FALSE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 	gtk_widget_show_all (hbox);
 
 	/* Listen for gconf changes */
