@@ -254,7 +254,7 @@ gconf_add_recent_key (GConfEditorWindow *window, const char *key)
 		gconf_client_set_list (window->client,
 				       "/apps/gconf-editor/recents", GCONF_VALUE_STRING, list, NULL);
 
-		if (GTK_WIDGET_VISIBLE (GTK_WIDGET (window->output_window)) &&
+		if (gtk_widget_get_visible (GTK_WIDGET (window->output_window)) &&
 	    				window->output_window_type == GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_RECENTS) 
 			gedit_output_window_prepend_line (GEDIT_OUTPUT_WINDOW (window->output_window),
 							  (gchar*) key, TRUE);
@@ -613,11 +613,12 @@ gconf_editor_window_test_expand_row (GtkTreeView       *tree_view,
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (data);
   GdkCursor *cursor;
 
-  if (!GTK_WIDGET_REALIZED (gconfwindow))
+  if (!gtk_widget_get_realized (GTK_WIDGET (gconfwindow)))
     return FALSE;
 
   cursor = gdk_cursor_new (GDK_WATCH);
-  gdk_window_set_cursor (GTK_WIDGET (gconfwindow)->window, cursor);
+  gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (gconfwindow)),
+                         cursor);
   gdk_cursor_unref (cursor);
 
   gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (gconfwindow)));
@@ -633,10 +634,10 @@ gconf_editor_window_row_expanded (GtkTreeView       *tree_view,
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (data);
 
-  if (!GTK_WIDGET_REALIZED (gconfwindow))
+  if (!gtk_widget_get_realized (GTK_WIDGET (gconfwindow)))
     return;
 
-  gdk_window_set_cursor (GTK_WIDGET (gconfwindow)->window, NULL);
+  gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (gconfwindow)), NULL);
   gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (gconfwindow)));
 }
 
@@ -651,15 +652,14 @@ static void
 gconf_editor_popup_window_set_as_default (GtkAction *action, GtkWidget *callback_data)
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (callback_data);
-  GtkWindow *window = GTK_WINDOW (callback_data);
 
   GtkTreeIter iter;
   GConfValue *value;
   char *path = NULL;
+  GtkWindow *window = GTK_WINDOW (callback_data);
   gboolean can_use_pk;
   
   can_use_pk = (gconfwindow->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL);
-  
   gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (gconfwindow->list_view)),
                                    NULL, &iter);
   gtk_tree_model_get (gconfwindow->sorted_list_model, &iter,
@@ -680,16 +680,13 @@ gconf_editor_popup_window_set_as_default (GtkAction *action, GtkWidget *callback
 
       if (!error)
         return;
-
       if (!can_use_pk)
         gconf_editor_window_popup_error_dialog (window, _("Could not sync value. Error was:\n%s"), error);
     }
   }
-
   if (can_use_pk) {
     gconf_client_suggest_sync (gconfwindow->client, NULL);
     gconf_pk_set_default_async (path,
-                                GDK_WINDOW_XWINDOW (GTK_WIDGET (window)->window),
                                 (GFunc) gconf_editor_popup_policykit_callback,
                                 g_object_ref (window), g_object_unref);
   }
@@ -699,15 +696,14 @@ static void
 gconf_editor_popup_window_set_as_mandatory (GtkAction *action, GtkWidget *callback_data)
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (callback_data);
-  GtkWindow *window = GTK_WINDOW (callback_data);
 
   GtkTreeIter iter;
   GConfValue *value;
   char *path = NULL;
+  GtkWindow *window = GTK_WINDOW (callback_data);
   gboolean can_use_pk;
   
   can_use_pk = (gconfwindow->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL);
-
   gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (gconfwindow->list_view)),
                                    NULL, &iter);
   gtk_tree_model_get (gconfwindow->sorted_list_model, &iter,
@@ -728,16 +724,13 @@ gconf_editor_popup_window_set_as_mandatory (GtkAction *action, GtkWidget *callba
 
       if (!error)
         return;
-      
       if (!can_use_pk)
         gconf_editor_window_popup_error_dialog (window, _("Could not sync value. Error was:\n%s"), error);
     }
   }
-
   if (can_use_pk) {
     gconf_client_suggest_sync (gconfwindow->client, NULL);
     gconf_pk_set_mandatory_async (path,
-                                  GDK_WINDOW_XWINDOW (GTK_WIDGET (window)->window),
                                   (GFunc) gconf_editor_popup_policykit_callback,
                                   g_object_ref (window), g_object_unref);
   }
@@ -934,10 +927,10 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 						  window->type != GCONF_EDITOR_WINDOW_TYPE_DEFAULTS);
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
 						  (gconf_util_can_edit_defaults () && window->type != GCONF_EDITOR_WINDOW_TYPE_DEFAULTS) ||
-						  (gconf_pk_can_set_default () && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
+						  (gconf_pk_can_set_default ("/") && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
 						  (gconf_util_can_edit_mandatory () && window->type != GCONF_EDITOR_WINDOW_TYPE_MANDATORY) ||
-						  (gconf_pk_can_set_mandatory () && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
+						  (gconf_pk_can_set_mandatory ("/") && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
 			
 			gtk_tree_path_free (path);
 		}
@@ -1030,18 +1023,17 @@ gconf_editor_window_list_view_popup_menu (GtkWidget *widget, GConfEditorWindow *
 
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view));
 	/* Select our row */
-	if (gtk_tree_selection_get_selected (selection, &window->list_model, &iter)) {
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
 					  TRUE);
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
 					  window->type != GCONF_EDITOR_WINDOW_TYPE_DEFAULTS);
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
 					  (gconf_util_can_edit_defaults () && window->type != GCONF_EDITOR_WINDOW_TYPE_DEFAULTS) ||
-					  (gconf_pk_can_set_default () && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
+					  (gconf_pk_can_set_default ("/") && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
 					  (gconf_util_can_edit_mandatory () && window->type != GCONF_EDITOR_WINDOW_TYPE_MANDATORY) ||
-					  (gconf_pk_can_set_mandatory () && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
-			
+					  (gconf_pk_can_set_mandatory ("/") && window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL));
 	}
 	else {
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
@@ -1057,7 +1049,7 @@ gconf_editor_window_list_view_popup_menu (GtkWidget *widget, GConfEditorWindow *
 	
 	gtk_menu_popup (GTK_MENU (window->popup_menu), NULL, NULL,
 			(GtkMenuPositionFunc) gconf_editor_window_list_view_popup_position, 
-			widget->window,
+			gtk_widget_get_window (widget),
 			0, gtk_get_current_event_time ());
 }
 
@@ -1299,10 +1291,13 @@ gconf_editor_window_setup_ui_prefs_handler (GConfEditorWindow *window)
 static void
 gconf_editor_window_style_set (GtkWidget *widget, GtkStyle *prev_style, GtkWidget *text_view)
 {
+	GtkStyle *style;
+
+	style = gtk_widget_get_style (widget);
 	gtk_widget_modify_base (text_view, GTK_STATE_NORMAL,
-				&GTK_WIDGET (widget)->style->bg[GTK_STATE_NORMAL]);
+				&style->bg[GTK_STATE_NORMAL]);
 	gtk_widget_modify_text (text_view, GTK_STATE_NORMAL,
-				&GTK_WIDGET (widget)->style->fg[GTK_STATE_NORMAL]);
+				&style->fg[GTK_STATE_NORMAL]);
 }
 
 void
@@ -1419,13 +1414,7 @@ gconf_editor_window_finalize (GObject *object)
 		gconf_client_notify_remove (client, window->icons_notify_id);
 
 	g_object_unref (client);
-
-	/* for some reason, the program crashes if I try to unref the client for
-         * the other window types.
-         */
-	if (window->type == GCONF_EDITOR_WINDOW_TYPE_NORMAL) {
-	  g_object_unref (window->client);
-        }
+	g_object_unref (window->client);
 
 	G_OBJECT_CLASS (gconf_editor_window_parent_class)->finalize (object);
     
