@@ -83,10 +83,10 @@ bool_button_toggled (GtkWidget *bool_button,
 		     gpointer   data)
 {
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (bool_button)))
-		gtk_label_set_label (GTK_LABEL (GTK_BIN (bool_button)->child),
+		gtk_label_set_label (GTK_LABEL (gtk_bin_get_child (GTK_BIN (bool_button))),
 				     _("T_rue"));
 	else
-		gtk_label_set_label (GTK_LABEL (GTK_BIN (bool_button)->child),
+		gtk_label_set_label (GTK_LABEL (gtk_bin_get_child (GTK_BIN (bool_button))),
 				     _("_False"));
 }
 
@@ -208,6 +208,7 @@ static void
 list_add_clicked (GtkButton *button,
 		  GConfKeyEditor *editor)
 {
+	GtkWidget *content_area;
 	GtkWidget *dialog;
 	GtkWidget *hbox;
 	GtkWidget *value_widget;
@@ -222,15 +223,17 @@ list_add_clicked (GtkButton *button,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 0);
 
 	label = gtk_label_new_with_mnemonic (_("_New list value:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -308,6 +311,7 @@ list_add_clicked (GtkButton *button,
 static void
 list_edit_element (GConfKeyEditor *editor)
 {
+	GtkWidget *content_area;
 	GtkWidget *dialog;
 	GtkWidget *hbox;
 	GtkWidget *value_widget;
@@ -324,15 +328,17 @@ list_edit_element (GConfKeyEditor *editor)
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 0);
 
 	label = gtk_label_new_with_mnemonic (_("_Edit list value:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -527,6 +533,7 @@ gconf_key_editor_class_init (GConfKeyEditorClass *klass)
 static void
 gconf_key_editor_init (GConfKeyEditor *editor)
 {
+	GtkWidget *content_area;
 	GtkWidget *hbox, *vbox, *framebox;
 	GtkWidget *label, *image;
 	GtkWidget *value_box;
@@ -540,15 +547,16 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
 				NULL);
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (editor));
 	gtk_dialog_set_default_response (GTK_DIALOG (editor), GTK_RESPONSE_OK);
-	
+
 	gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
 	gtk_dialog_set_has_separator (GTK_DIALOG (editor), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (editor), FALSE);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 
 	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), vbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_widget_show_all (vbox);
 
