@@ -25,7 +25,6 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libintl.h>
 #include <string.h>
 
 #include "gconf-stock-icons.h"
@@ -50,18 +49,17 @@ gconf_search_dialog_class_init (GConfSearchDialogClass *klass)
 
 
 static void
-gconf_search_not_found_dialog (GConfEditorWindow *window) 
+gconf_search_not_found_dialog (GConfSearchDialog *dialog) 
 {
 	GtkWidget *not_found_dialog;
 	
-	not_found_dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+	not_found_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
 						   GTK_DIALOG_DESTROY_WITH_PARENT,
 						   GTK_MESSAGE_ERROR,
 						   GTK_BUTTONS_CLOSE,
 						   _("Pattern not found"));
 	gtk_dialog_run (GTK_DIALOG (not_found_dialog));
 	gtk_widget_destroy (GTK_WIDGET (not_found_dialog));
-	
 }
 
 static void
@@ -81,18 +79,20 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 {
 	GConfEditorWindow *window;
 	GdkCursor *cursor;
+	GdkWindow *dialog_window;
 
 	gchar *pattern;
 	int res;
-	
+
 	window = g_object_get_data (G_OBJECT (dialog), "editor-window");
 	gedit_output_window_clear (GEDIT_OUTPUT_WINDOW (window->output_window));
 	window->output_window_type = GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_SEARCH;
 
 	pattern = g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->entry)));
+	dialog_window = gtk_widget_get_window (GTK_WIDGET (dialog));
 
 	cursor = gdk_cursor_new (GDK_WATCH);
-	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, cursor);
+	gdk_window_set_cursor (dialog_window, cursor);
 	gdk_cursor_unref (cursor);
 	gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
 
@@ -105,20 +105,14 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 
 	g_free (pattern);
 
-	if (dialog != NULL) {
-#if 0
-		g_signal_handlers_disconnect_by_func (dialog->entry,
-						      G_CALLBACK (gconf_search_entry_changed), dialog);
-		g_signal_handlers_disconnect_by_func (dialog->search_button,
-						      G_CALLBACK (gconf_search_dialog_search), dialog);
-#endif
-		gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
+	if (dialog != NULL && GTK_IS_WIDGET (dialog)) {
+		gdk_window_set_cursor (dialog_window, NULL);
 		gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
 
 		if (res != 0) {
 			gtk_widget_destroy (GTK_WIDGET (dialog));
 		} else {
-			gconf_search_not_found_dialog(window);
+			gconf_search_not_found_dialog (dialog);
 		}
 	}
 }
@@ -126,21 +120,23 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 static void
 gconf_search_dialog_init (GConfSearchDialog *dialog)
 {
+	GtkWidget *action_area, *content_area;
 	GtkWidget *hbox;
 	GtkWidget *vbox;
 	GtkWidget *label;
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	
 	hbox = gtk_hbox_new (FALSE, 12);
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Find"));
@@ -157,7 +153,7 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 	g_signal_connect (dialog->search_button, "clicked",
 			  G_CALLBACK (gconf_search_dialog_search), dialog);
 
-	GTK_WIDGET_SET_FLAGS(dialog->search_button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (dialog->search_button, TRUE);
 	gtk_window_set_default(GTK_WINDOW(dialog), dialog->search_button);
 	gtk_entry_set_activates_default(GTK_ENTRY(dialog->entry), TRUE);
 	
@@ -172,9 +168,9 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 	dialog->search_in_values = gtk_check_button_new_with_mnemonic (_("Search also in key _values"));
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->search_in_values, TRUE, TRUE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), dialog->search_button, TRUE, TRUE, 0);
-	gtk_widget_show_all (GTK_DIALOG(dialog)->action_area);
+	gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (action_area), dialog->search_button, TRUE, TRUE, 0);
+	gtk_widget_show_all (action_area);
 	gtk_widget_show_all (vbox);
 	
 	gtk_widget_show_all (hbox);
